LLVMAtomicRMWBinOp

Enum LLVMAtomicRMWBinOp 

#[repr(C)]
pub enum LLVMAtomicRMWBinOp {
Show 21 variants LLVMAtomicRMWBinOpXchg = 0, LLVMAtomicRMWBinOpAdd = 1, LLVMAtomicRMWBinOpSub = 2, LLVMAtomicRMWBinOpAnd = 3, LLVMAtomicRMWBinOpNand = 4, LLVMAtomicRMWBinOpOr = 5, LLVMAtomicRMWBinOpXor = 6, LLVMAtomicRMWBinOpMax = 7, LLVMAtomicRMWBinOpMin = 8, LLVMAtomicRMWBinOpUMax = 9, LLVMAtomicRMWBinOpUMin = 10, LLVMAtomicRMWBinOpFAdd = 11, LLVMAtomicRMWBinOpFSub = 12, LLVMAtomicRMWBinOpFMax = 13, LLVMAtomicRMWBinOpFMin = 14, LLVMAtomicRMWBinOpUIncWrap = 15, LLVMAtomicRMWBinOpUDecWrap = 16, LLVMAtomicRMWBinOpUSubCond = 17, LLVMAtomicRMWBinOpUSubSat = 18, LLVMAtomicRMWBinOpFMaximum = 19, LLVMAtomicRMWBinOpFMinimum = 20,
}

Variants



LLVMAtomicRMWBinOpXchg = 0



LLVMAtomicRMWBinOpAdd = 1



LLVMAtomicRMWBinOpSub = 2



LLVMAtomicRMWBinOpAnd = 3



LLVMAtomicRMWBinOpNand = 4



LLVMAtomicRMWBinOpOr = 5



LLVMAtomicRMWBinOpXor = 6



LLVMAtomicRMWBinOpMax = 7



LLVMAtomicRMWBinOpMin = 8



LLVMAtomicRMWBinOpUMax = 9



LLVMAtomicRMWBinOpUMin = 10



LLVMAtomicRMWBinOpFAdd = 11



LLVMAtomicRMWBinOpFSub = 12



LLVMAtomicRMWBinOpFMax = 13



LLVMAtomicRMWBinOpFMin = 14



LLVMAtomicRMWBinOpUIncWrap = 15



LLVMAtomicRMWBinOpUDecWrap = 16



LLVMAtomicRMWBinOpUSubCond = 17

Subtracts the value only if no unsigned overflow.



LLVMAtomicRMWBinOpUSubSat = 18

Subtracts the value, clamping to zero.



LLVMAtomicRMWBinOpFMaximum = 19

Sets the value if it’s greater than the original using an floating point comparison and return the old one.



LLVMAtomicRMWBinOpFMinimum = 20

Sets the value if it’s smaller than the original using an floating point comparison and return the old one.